﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using NUnit.Framework;
using gdio.common.objects;
using gdio.unity_api.v2;
using gdio.unity_api;

namespace VRDemo_Tests
{
    [TestFixture]
    public class VRDemo_Tests
    {
        static string mode = "IDE";
        //static string mode = "standalone";

        // IP address of the test host. Use localhost for local.
        //static string host = "192.168.86.21"; // replace device IP address. Must be run in 'standalone' mode for Mobile
        static string host = "localhost";

        //static string pathToExe = @"C:\Path\To\Executable.exe";
        //static string pathToExe = @"/Path/To/Executable.app/Contents/MacOS/Binary";
        static string pathToExe = null;

        ApiClient api;

        // PID for standalone execution
        int PID;

        public string testMode = TestContext.Parameters.Get("Mode", mode);
        public string testHost = TestContext.Parameters.Get("Host", host);
        public string executablePath = TestContext.Parameters.Get("executablePath", pathToExe);

        [OneTimeSetUp]
        public void Connect()
        {
            try
            {
                api = new ApiClient();

                if (executablePath != null && testMode == "standalone")
                {
                    PID = ApiClient.Launch(executablePath);
                    api.Wait(5000);
                    Console.WriteLine($"Launching standalone executable with PID: {PID}");
                    api.Connect(testHost);
                }
                else if (executablePath == null && testMode == "IDE")
                {
                    api.Connect(testHost, 19734, true, 30);
                }
                else api.Connect(testHost, 19734, false, 30);
            }
            catch (Exception e)
            {
                Console.WriteLine(e.ToString());
            }

            api.Wait(5000);

            api.EnableHooks(HookingObject.XRLEGACY);
        }

        [OneTimeTearDown]
        public void Disconnect()
        {
            api.RemoveInputDevices();
            api.DisableHooks(HookingObject.ALL);
            api.Disconnect();
            api.StopEditorPlay();
        }

        [Test, Order(0)]
        public void InputTest()
        {
            // Required for enabling teleport in the scene without placing the book on the pedestal
            api.SetObjectFieldValue("//*[@name='XR Rig']/fn:component('MasterController')", "DisableSetupForDebug", true );
            api.Wait(1000);

            // Enable Legacy XR hooks
            api.EnableHooks(HookingObject.XRLEGACY);
            var recording = new Recording();
            recording.Replay(api);
        }
    }
}
